#!/usr/bin/python
#	
#	updateSite.py - Part of PubTal
#
#	Usage: updateSite.py site.config [content-dir | content-file] [...]
#
#	Copyright (c) 2003 Colin Stewart (http://www.owlfish.com/)
#	All rights reserved.
#		
#	Redistribution and use in source and binary forms, with or without
#	modification, are permitted provided that the following conditions
#	are met:
#	1. Redistributions of source code must retain the above copyright
#	   notice, this list of conditions and the following disclaimer.
#	2. Redistributions in binary form must reproduce the above copyright
#	   notice, this list of conditions and the following disclaimer in the
#	   documentation and/or other materials provided with the distribution.
#	3. The name of the author may not be used to endorse or promote products
#	   derived from this software without specific prior written permission.
#		
#	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
#	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
#	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
#	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
#	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
#	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#	
#	If you make any bug fixes or feature enhancements please let me know!
#

try:
	import logging
	logging.basicConfig()
	root = logging.getLogger()
	#root.setLevel (logging.DEBUG)
	root.setLevel (logging.INFO)
	talLogger = logging.getLogger ("simpleTAL")
	talLogger.setLevel (logging.INFO)
	talesLogger = logging.getLogger ("simpleTALES")
	talesLogger.setLevel (logging.INFO)

except:
	from simpletal import DummyLogger as logging
	
import sys, os.path, os, stat
import pubtal

from pubtal import SitePublisher, SiteConfiguration
					
class PathResolver:
	def __init__ (self, config):
		self.config = config
		self.currentContent = []
		self.log = logging.getLogger ('PathResolver')
		self.contentDir = config.getContentDir()
		self.ignoreFilters = config.getIgnoreFilters()
		
	def getPages (self, target):
		""" Returns a Page list
		
			target is either:
				None 		- Get all files
				List of files or dir paths.
		"""
		result = []
		
		if (target is None):
			self.log.info ("Building whole site.")
			targetList = [self.contentDir]
		else:
			targetList = []
			for t in target:
				targetList.append (os.path.abspath (t))
			
		self.log.debug ("Target path: %s" % str (targetList))
		for targetPath in targetList:
			self.log.debug ("Checking target path: %s" % targetPath)
			# Are we doing just one file or a dir?
			if (os.path.isfile (targetPath)):
				# Just get this entry
				result.append (self.config.getPage (targetPath))
			else:
				os.path.walk (targetPath, self.walkPaths, None)
				for content in self.currentContent:
					result.append (self.config.getPage (content))
		self.currentContent = []
		return result
		
	def walkPaths (self, arg, dirname, names):
		for name in names:
			self.log.debug ("Checking path %s for content." % os.path.join (dirname, name))
			realName = os.path.join (dirname, name)
			if (os.path.isfile (realName)):
				contentFile = 1
				for filter in self.ignoreFilters:
					if (filter.match (realName)):
						contentFile = 0
				if (contentFile):
					self.currentContent.append (realName)
				else:
					self.log.debug ("Ignoring path %s" % realName)

class UpdateSite:
	def __init__ (self, configFile, path=None):
		self.config = SiteConfiguration.SiteConfig (configFile)
		self.pathResolver = PathResolver (self.config)
		self.target = path
		self.log = logging.getLogger ("UpdateSite")
		self.publisher = SitePublisher.PagePublisher (self.config)
		
	def buildSite (self):
		pathsToBuild = self.pathResolver.getPages (self.target)
		self.log.debug ("Found paths: %s" % str (pathsToBuild))
		for aPage in pathsToBuild:
			self.log.info ("Publishing: %s" % str (aPage))
			self.publisher.publish (aPage)
		
if __name__ == '__main__':
	#logging.debug ("Arguments: " + str (sys.argv))
	if (len (sys.argv) < 2):
		print "Usage: %s configFile [paths]" % sys.argv[0]
		sys.exit (1)
		
	if (len (sys.argv) == 2):
		target = None
	else:
		target = sys.argv [2:]
			
	update = UpdateSite (sys.argv[1], target)
	update.buildSite()
